#!/bin/bash
#
######################################################################
#
#	install.no.catalina.update.red.badge.launchagent.sh
#
#	Samuel Herschbein
#	sam@SamIsIT.com
#	sherschbein@me.com
#
#	Details and Revision History are in README.txt
#
######################################################################
#
#	Get the script's name.
thisScriptName="${0##*/}"
#	Get the script's path with trailing slash.
thisScriptPath="${0%/*}/"
#
#	Script must be run with sudo.
[[ "$(whoami)" != "root" ]] && { printf "$thisScriptName must be run with sudo.\n\n"; exit; }
#
#	Inform & quit if launch agent already running (bootstrapped).
launchctlResult=$(sudo launchctl print system | grep 'com.samisit.no.catalina.update.red.badge' | awk '{print $3}')
[[ "$launchctlResult" != "" ]] && { printf "\ncom.samisit.no.catalina.update.red.badge Launch Agent already running, quitting.\n\n"; exit; }
#
#	Make sure the plist is in same directory as this script.
[[ ! -f "$thisScriptPath""com.samisit.no.catalina.update.red.badge.plist" ]] && { printf "File $thisScriptPath""com.samisit.no.catalina.update.red.badge.plist not found.\n\n"; exit; }
#
#	First tell Software Update to ignore Catalina.
softwareupdateError=$(sudo softwareupdate --ignore "macOS Catalina" 2>&1)
[[ "$?" -ne 0 ]] && { printf "\n%s\n\n" "${softwareupdateError##*: } error telling Software Update to ignore Catalina.\n\n"; exit; }
#
#	Copy the plist, then set ownership & permissions.
cp "$thisScriptPath""com.samisit.no.catalina.update.red.badge.plist" /Library/LaunchAgents
chown root:wheel /Library/LaunchAgents/com.samisit.no.catalina.update.red.badge.plist
chmod 644 /Library/LaunchAgents/com.samisit.no.catalina.update.red.badge.plist
#
#	Bootstrap the LaunchAgent.
launchctlError=$(launchctl bootstrap system /Library/LaunchAgents/com.samisit.no.catalina.update.red.badge.plist 2>&1)
if [[ "$?" -ne 0 ]]; then
	printf "\n%s\n\n" "Error bootstrapping com.samisit.no.catalina.update.red.badge: ${launchctlError##*: }."
else
	printf "\n%s\n\n" "com.samisit.no.catalina.update.red.badge LaunchAgent was bootstrapped successfully."
fi
#
